Transport Analysis
==============================
[//]: # (Badges)

| **Latest release** | [![Last release tag](https://img.shields.io/github/release-pre/MDAnalysis/transport-analysis.svg)](https://github.com/MDAnalysis/transport-analysis/releases) ![GitHub commits since latest release (by date) for a branch](https://img.shields.io/github/commits-since/MDAnalysis/transport-analysis/latest)  [![Documentation Status](https://readthedocs.org/projects/transport-analysis/badge/?version=latest)](https://transport-analysis.readthedocs.io/en/latest/?badge=latest)|
| :------ | :------- |
| **Status** | [![GH Actions Status](https://github.com/MDAnalysis/transport-analysis/actions/workflows/gh-ci.yaml/badge.svg)](https://github.com/MDAnalysis/transport-analysis/actions?query=branch%3Amain+workflow%3Agh-ci) [![codecov](https://codecov.io/gh/MDAnalysis/transport-analysis/branch/main/graph/badge.svg)](https://codecov.io/gh/MDAnalysis/transport-analysis/branch/main) |
| **Community** | [![License: GPL v2](https://img.shields.io/badge/License-GPLv2-blue.svg)](https://www.gnu.org/licenses/gpl-2.0)  [![Powered by MDAnalysis](https://img.shields.io/badge/powered%20by-MDAnalysis-orange.svg?logoWidth=16&logo=data:image/x-icon;base64, )](https://www.mdanalysis.org)|

A Python package to compute and analyze transport properties.

Transport Analysis is bound by a [Code of Conduct](https://github.com/MDAnalysis/transport-analysis/blob/main/CODE_OF_CONDUCT.md).

### Installation

To build Transport Analysis from source,
we highly recommend using virtual environments.
If possible, we strongly recommend that you use
[Anaconda](https://docs.conda.io/en/latest/) as your package manager.
Below we provide instructions both for `conda` and
for `pip`.

#### With conda

Ensure that you have [conda](https://docs.conda.io/projects/conda/en/latest/user-guide/install/index.html) installed.

Create a virtual environment and activate it:

```
conda create --name transport_analysis
conda activate transport_analysis
```

Install the development and documentation dependencies:

```
conda env update --name transport_analysis --file devtools/conda-envs/test_env.yaml
conda env update --name transport_analysis --file docs/requirements.yaml
```

Build this package from source:

```
pip install -e .
```

If you want to update your dependencies (which can be risky!), run:

```
conda update --all
```

And when you are finished, you can exit the virtual environment with:

```
conda deactivate
```

#### With pip

To build the package from source, run:

```
pip install -e .
```

If you want to create a development environment, install
the dependencies required for tests and docs with:

```
pip install -e ".[test,doc]"
```

### Copyright

The Transport Analysis source code is hosted at https://github.com/MDAnalysis/transport-analysis
and is available under the GNU General Public License, version 2 (see the file [LICENSE](https://github.com/MDAnalysis/transport-analysis/blob/main/LICENSE)).

Copyright (c) 2023, Xu Hong Chen


#### Acknowledgements
 
Project based on the 
[MDAnalysis Cookiecutter](https://github.com/MDAnalysis/cookiecutter-mda) version 0.1.
Please cite [MDAnalysis](https://github.com/MDAnalysis/mdanalysis#citation) when using Transport Analysis in published work.
